/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/* Nome: 0009_DENSTPO_USR_EXPORTATITU_DENADAI.sql                             */
/*                                                                            */
/* Descrio:                                                                 */
/* Procedure destinada a exportar informaes das vendas/ movimentos de caixa */
/* geradas no sistema da Teknisa para serem importadas no sistema Microsiga e,*/
/* para isso, a procedure alimentar uma tabela intermediria entre os dois   */
/* sistemas .(Tabelas pertencentes ao banco de dados do sistema da Microsiga).*/
/*                                                                            */
/* Criao: 20/08/2008 - Leonardo Matos                                       */
/******************************************************************************/

CREATE OR REPLACE
PROCEDURE USR_EXPORTATITU_DENADAI IS
   V_DTGRV        DATE;
   V_HRGRV        VARCHAR2(04);

   V_FILIAL       VARCHAR2(10);
   V_IDTPREC      VARCHAR2(1);
   V_PARCELA      VARCHAR2(1);
   V_CLIENTE      VARCHAR2(14);
   V_NUMC         INTEGER;

   V_NOVOCODIGO   INTEGER;
   V_SEQTIPORECE  VARCHAR2(26);
   V_COUNT        INTEGER;
   V_DOCUMENTO    VARCHAR2(20);
BEGIN
   V_DTGRV := NULL;
   V_HRGRV := NULL;

   V_COUNT     := 0;
   V_IDTPREC   := '';
   V_PARCELA   := '';
   V_DOCUMENTO := ' ';

   V_SEQTIPORECE := 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';

   /* Retorna data e hora de exportao */
   BEGIN
      SELECT TO_DATE(SYSDATE), TO_CHAR(SYSDATE,'HH24MI')
        INTO V_DTGRV, V_HRGRV
        FROM DUAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_DTGRV := NULL;
         V_HRGRV := NULL;
   END;

   FOR C_TITEXPORT IN
      (SELECT A.CDFILIAL, A.CDCAIXA, A.NRSEQVENDA, A.DTVENDA,
              A.CDTIPORECE, A.IDTIPORECE, A.CDADMINCART, A.NRDIASADMI, (A.VRVALOR  - NVL(B.VRVALOR,0)) AS VRVALOR
         FROM (SELECT V.CDFILIAL, V.CDCAIXA, V.NRSEQVENDA, V.DTVENDA,
                      M.CDTIPORECE, T.IDTIPORECE, T.CDADMINCART, NVL(T.NRDIASADMI,'0') AS NRDIASADMI, SUM(M.VRMOVIVEND) AS VRVALOR
                 FROM VENDA V, MOVCAIXA M, TIPORECE T, 
                      (SELECT DISTINCT(CDFILIAL)
                         FROM FILGRUPFILI
                        WHERE USR_IDPROTHEUS = 'S') F
                WHERE NVL(V.USR_IDEXPORTA, 'S') = 'S'
                  AND V.USR_DTEXPORTA IS NULL
                  AND M.CDFILIAL = V.CDFILIAL
                  AND M.CDCAIXA = V.CDCAIXA
                  AND M.NRSEQVENDA = V.NRSEQVENDA
                  AND M.IDTIPOMOVIVE = 'E'
                  AND T.CDTIPORECE = M.CDTIPORECE
                  AND T.IDTIPORECE IN ('1','2','3','4','5')
                  AND V.CDFILIAL = F.CDFILIAL
                GROUP BY V.CDFILIAL, V.CDCAIXA, V.NRSEQVENDA, V.DTVENDA,
                         M.CDTIPORECE, T.IDTIPORECE, T.CDADMINCART, NVL(T.NRDIASADMI,'0')
              ) A,
              (SELECT V.CDFILIAL, V.CDCAIXA, V.NRSEQVENDA, T.IDTIPORECE, SUM(M.VRMOVIVEND) AS VRVALOR
                 FROM VENDA V, MOVCAIXA M, TIPORECE T, 
                      (SELECT DISTINCT(CDFILIAL)
                         FROM FILGRUPFILI
                        WHERE USR_IDPROTHEUS = 'S') F
                WHERE NVL(V.USR_IDEXPORTA, 'S') = 'S'
                  AND V.USR_DTEXPORTA IS NULL
                  AND M.CDFILIAL = V.CDFILIAL
                  AND M.CDCAIXA = V.CDCAIXA
                  AND M.NRSEQVENDA = V.NRSEQVENDA
                  AND M.IDTIPOMOVIVE = 'S'
                  AND T.CDTIPORECE = M.CDTIPORECE
                  AND T.IDTIPORECE = '4'
                  AND V.CDFILIAL = F.CDFILIAL
                GROUP BY V.CDFILIAL, V.CDCAIXA, V.NRSEQVENDA, T.IDTIPORECE
              ) B
        WHERE A.CDFILIAL = B.CDFILIAL (+)
          AND A.CDCAIXA = B.CDCAIXA (+)
          AND A.NRSEQVENDA = B.NRSEQVENDA (+)
          AND A.IDTIPORECE = B.IDTIPORECE (+)
        ORDER BY A.CDFILIAL, A.CDCAIXA, A.NRSEQVENDA, A.CDTIPORECE
       )
   LOOP
      SELECT MAX(CDGRUPFILI)
        INTO V_FILIAL
        FROM FILGRUPFILI
       WHERE CDFILIAL = C_TITEXPORT.CDFILIAL
         AND USR_IDPROTHEUS = 'S';

      IF NOT V_FILIAL IS NULL THEN

         IF (SUBSTR(V_DOCUMENTO,1,17) <> (C_TITEXPORT.CDFILIAL||C_TITEXPORT.CDCAIXA||C_TITEXPORT.NRSEQVENDA)) THEN
            V_DOCUMENTO := (C_TITEXPORT.CDFILIAL||C_TITEXPORT.CDCAIXA||C_TITEXPORT.NRSEQVENDA);
            V_COUNT     := 0;
         END IF;

         V_COUNT := V_COUNT + 1;

         V_PARCELA := SUBSTR(V_SEQTIPORECE, V_COUNT, 1);
         V_IDTPREC := C_TITEXPORT.IDTIPORECE;

         V_CLIENTE := '';

         IF NOT C_TITEXPORT.CDADMINCART IS NULL THEN
            V_CLIENTE := SUBSTR(C_TITEXPORT.CDADMINCART,1,14);
         ELSE
            SELECT SUBSTR(replace(replace(replace(MAX(NRINSJURFILI), '-', ''),'.',''),'/',''),1,14)
              INTO V_CLIENTE
              FROM FILIAL
             WHERE CDFILIAL = C_TITEXPORT.CDFILIAL;
         END IF;

         /* Retorna o sequencial para a tabela */
         BEGIN
            SELECT WC_IDTITRE.NEXTVAL
              INTO V_NOVOCODIGO
              FROM DUAL;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_NOVOCODIGO := 1;
         END;

         SELECT NVL(MAX(WC_IDTITRE),0)
           INTO V_NUMC
           FROM USR_ZWC
          WHERE CDFILIAL = C_TITEXPORT.CDFILIAL
            AND CDCAIXA = C_TITEXPORT.CDCAIXA
            AND NRSEQVENDA = C_TITEXPORT.NRSEQVENDA
            AND CDTIPORECE = C_TITEXPORT.CDTIPORECE
            AND WC_TPEDI = '1';

         IF V_NUMC = 0 THEN

            INSERT INTO USR_ZWC (
               CDFILIAL, CDCAIXA, NRSEQVENDA, CDTIPORECE,
               WC_IDTITRE, WC_EMPRESA, WC_FILIAL , WC_PREFIXO,
               WC_NUM    , WC_IDTPREC, WC_PARCELA,
               WC_CGC    , WC_EMISSAO,
               WC_VENCTO , WC_VENCREA,
               WC_VALOR  , WC_VLCRUZ , WC_TPEDI,
               WC_DTGRV  , WC_HRGRV  ,
               WC_DTIMP  , WC_HRIMP)
            VALUES
               (C_TITEXPORT.CDFILIAL, C_TITEXPORT.CDCAIXA, C_TITEXPORT.NRSEQVENDA, C_TITEXPORT.CDTIPORECE,
                V_NOVOCODIGO, SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2), C_TITEXPORT.CDCAIXA,
                SUBSTR(C_TITEXPORT.NRSEQVENDA, 2, 9), V_IDTPREC, V_PARCELA,
                V_CLIENTE, TO_DATE(C_TITEXPORT.DTVENDA),
                TO_DATE(C_TITEXPORT.DTVENDA + TO_NUMBER(C_TITEXPORT.NRDIASADMI)), TO_DATE(C_TITEXPORT.DTVENDA),
                ROUND(C_TITEXPORT.VRVALOR,2), ROUND(C_TITEXPORT.VRVALOR,2), '1',
                V_DTGRV, V_HRGRV,
                NULL, '');
         ELSE
            INSERT INTO USR_ZWC (
               CDFILIAL, CDCAIXA, NRSEQVENDA, CDTIPORECE,
               WC_IDTITRE, WC_EMPRESA, WC_FILIAL , WC_PREFIXO,
               WC_NUM    , WC_IDTPREC, WC_PARCELA,
               WC_CGC    , WC_EMISSAO,
               WC_VENCTO , WC_VENCREA,
               WC_VALOR  , WC_VLCRUZ , WC_TPEDI,
               WC_DTGRV  , WC_HRGRV  ,
               WC_DTIMP  , WC_HRIMP)
            VALUES
               (C_TITEXPORT.CDFILIAL, C_TITEXPORT.CDCAIXA, C_TITEXPORT.NRSEQVENDA, C_TITEXPORT.CDTIPORECE,
                V_NOVOCODIGO, SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2), C_TITEXPORT.CDCAIXA,
                SUBSTR(C_TITEXPORT.NRSEQVENDA, 2, 9), V_IDTPREC, V_PARCELA,
                V_CLIENTE, TO_DATE(C_TITEXPORT.DTVENDA),
                TO_DATE(C_TITEXPORT.DTVENDA + TO_NUMBER(C_TITEXPORT.NRDIASADMI)), TO_DATE(C_TITEXPORT.DTVENDA),
                ROUND(C_TITEXPORT.VRVALOR,2), ROUND(C_TITEXPORT.VRVALOR,2), '2',
                V_DTGRV, V_HRGRV,
                NULL, '');

            /* Retorna o sequencial para a tabela */
            BEGIN
               SELECT WC_IDTITRE.NEXTVAL
                 INTO V_NOVOCODIGO
                 FROM DUAL;
            EXCEPTION
               WHEN NO_DATA_FOUND THEN
                  V_NOVOCODIGO := 1;
            END;

            INSERT INTO USR_ZWC (
               CDFILIAL, CDCAIXA, NRSEQVENDA, CDTIPORECE,
               WC_IDTITRE, WC_EMPRESA, WC_FILIAL , WC_PREFIXO,
               WC_NUM    , WC_IDTPREC, WC_PARCELA,
               WC_CGC    , WC_EMISSAO,
               WC_VENCTO , WC_VENCREA,
               WC_VALOR  , WC_VLCRUZ , WC_TPEDI,
               WC_DTGRV  , WC_HRGRV  ,
               WC_DTIMP  , WC_HRIMP)
            VALUES
               (C_TITEXPORT.CDFILIAL, C_TITEXPORT.CDCAIXA, C_TITEXPORT.NRSEQVENDA, C_TITEXPORT.CDTIPORECE,
                V_NOVOCODIGO, SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2), C_TITEXPORT.CDCAIXA,
                SUBSTR(C_TITEXPORT.NRSEQVENDA, 2, 9), V_IDTPREC, V_PARCELA,
                V_CLIENTE, TO_DATE(C_TITEXPORT.DTVENDA),
                TO_DATE(C_TITEXPORT.DTVENDA + TO_NUMBER(C_TITEXPORT.NRDIASADMI)), TO_DATE(C_TITEXPORT.DTVENDA),
                ROUND(C_TITEXPORT.VRVALOR,2), ROUND(C_TITEXPORT.VRVALOR,2), '1',
                V_DTGRV, V_HRGRV,
                NULL, '');
         END IF;

         UPDATE VENDA
            SET USR_IDEXPORTA = 'N',
                USR_DTEXPORTA = SYSDATE
          WHERE CDFILIAL = C_TITEXPORT.CDFILIAL
            AND CDCAIXA = C_TITEXPORT.CDCAIXA
            AND NRSEQVENDA = C_TITEXPORT.NRSEQVENDA;
      END IF;
   END LOOP;
   COMMIT;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('USR_EXPORTATITU_DENADAI','5.09.000'); END;
/

